/*
 * AccessServlet.java - a sample VolanoChat member access servlet.
 */

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * This class serves as a sample VolanoChat membership database access servlet.
 *
 * @version 1.0
 * @author  John Neffenger
 */
public class AccessServlet extends MemberServlet implements Constants {
    private static final String SERVLET_VERSION = "1.0";

    /**
     * Returns the servlet name and version.
     *
     * @return information about this servlet.
     */
    public String getServletInfo() {
        return getServletInfo(SERVLET_VERSION);
    }

    /**
     * Initializes the servlet by preparing the query statement.
     *
     * @throws ServletException if an error occurs initializing the servlet.
     */
    public void init() throws ServletException {
        init(ACCESS_QUERY);
    }

    /**
     * Processes an HTTP GET request.
     *
     * @param request  the HTTP servlet request.
     * @param response the HTTP servlet response.
     * @throws IOException if an input or output error occurs while processing
     *         the request.
     * @throws ServletException if the servlet is unable to process the request.
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, IOException {
        response.setContentType(CONTENT_TYPE);
        PrintWriter writer = new PrintWriter(response.getWriter());
        try {
            // Get the HTTP request parameters.
            String name = getParameter(request, NAME_PARAMETER);
            String password = getParameter(request, PASSWORD_PARAMETER);

            // Get the database row for the given member name.
            statement.setString(NAME_INDEX, name);
            String memberPassword = null;
            String memberProfile = null;
            String memberDocument = null;
            ResultSet results = statement.executeQuery();
            if (results.next()) {
                memberPassword = results.getString(PASSWORD_FIELD);
                memberProfile = results.getString(PROFILE_FIELD);
                memberDocument = results.getString(LINK_FIELD);
            }
            results.close();

            // Return the HTTP response.
            if (memberPassword != null && password.equals(memberPassword)) {
                writer.println(TRUE);
                writer.println(memberProfile == null ? "" : memberProfile);
                if (memberDocument != null && memberDocument.length() > 0) {
                    writer.println(TRUE);
                }
                else {
                    writer.println(FALSE);
                }
            }
            else {
                writer.println(FALSE);
            }
        }
        catch (RuntimeException e) {
            throw e;
        }
        catch (Exception e) {
            writer.println(ERROR);
            writer.println(e);
        }
        writer.close();
    }
}
